NetworkCancelToken class

网络取消令牌

Constructors

NetworkCancelToken()

Properties

cancelError → DioException?
If request have been canceled, save the cancel error.
no setterinherited
cancelTokenKey String
获取取消令牌key
no setter
hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether the token is cancelled.
no setterinherited
requestOptions ↔ RequestOptions?
Corresponding request options for the request.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whenCancel Future<DioException>
When cancelled, this future will be resolved.
no setterinherited

Methods

cancel([Object? reason]) → void
Cancel the request with the given reason.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited